@@ -12,25 +12,24 @@
 
 """Package metadata for refitt."""
 
+
 __appname__     = 'refitt'
-__version__     = '0.10.3'
-__authors__     = """\
-Dan Milisavljevic, Ph.D. <dmilisav@purdue.edu>;
-Niharika Sravan, Ph.D. <nsravan@purdue.edu>;
-Geoffrey Lentner, M.Sc. <glentner@purdue.edu>;
-Mark Linvill <mlinvill@purdue.edu>
-"""
+__version__     = '0.12.2'
+__authors__     = ['Dan Milisavljevic, Ph.D. <dmilisav@purdue.edu>',
+                   'Niharika Sravan, Ph.D. <nsravan@purdue.edu>',
+                   'Geoffrey Lentner, M.Sc. <glentner@purdue.edu>',
+                   'Mark Linvill <mlinvill@purdue.edu>']
 __developer__   = 'Geoffrey Lentner'
-__contact__     = '<glentner@purdue.edu>'
+__contact__     = 'glentner@purdue.edu'
 __license__     = 'Apache License 2.0'
 __website__     = 'https://github.com/refitt/refitt'
-__copyright__   = 'REFITT Team 2019.'
+__copyright__   = 'REFITT Team 2019'
 __description__ = 'The Recommender Engine for Intelligent Transient Tracking.'
-__keywords__    = 'astronomy science machine-learning service'
+__keywords__    = 'astronomy science machine-learning recommendation service'
 __ascii_art__   = r"""
     ____  ____________________________
    / __ \/ ____/ ____/  _/_  __/_  __/
   / /_/ / __/ / /_   / /  / /   / /
  / _, _/ /___/ __/ _/ /  / /   / /
 /_/ |_/_____/_/   /___/ /_/   /_/
-"""
\ No newline at end of file
+"""
